"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rules_1 = require("./rules");
const ensure_1 = require("@commitlint/ensure");
/**
 * Get forced case for rule
 * @param rule to parse
 * @return transform function applying the enforced case
 */
function getCaseFn(rule) {
    const noop = (input, delimiter) => Array.isArray(input) ? input.join(delimiter) : input;
    if (!rule || !(0, rules_1.ruleIsActive)(rule) || (0, rules_1.ruleIsNotApplicable)(rule)) {
        return noop;
    }
    const value = rule[2];
    const caseList = Array.isArray(value) ? value : [value];
    return (input, delimiter) => {
        let matchedCase = caseList[0];
        const segments = Array.isArray(input) ? input : [input];
        for (const segment of segments) {
            const check = caseList.find((a) => (0, ensure_1.case)(segment, a));
            if (check) {
                matchedCase = check;
                break;
            }
        }
        return segments
            .map((segment) => {
            return (0, ensure_1.toCase)(segment, matchedCase);
        })
            .join(delimiter);
    };
}
exports.default = getCaseFn;
//# sourceMappingURL=case-fn.js.map