/** Tests if the specified value is null or undefined.
 *
 * Useful as the predicate of filter functions and similar. */
export declare function isNull<T>(value: unknown): value is null | undefined;
/** Tests if the specified value is null or undefined.
 *
 * Useful as the predicate of filter functions and similar. */
export declare function isNotNull<T>(value: T | null | undefined): value is T;
/** Asserts that the specified value is neither null nor undefined, and
 * returns it.
 *
 * @throws TypeError if the value is null or undefined */
export declare function notNull<T>(value: T | null | undefined): T;
/** Returns the specified value, or the default value if the specified value
 * is null or undefined.
 *
 * If the default value is expensive to compute, consider using
 * {@link mapNull} instead. */
export declare function defaultValue<T>(nullable: T | undefined | null, defaultValue: T): T;
/** Returns a function that returns the specified value, or the default value
 * if the specified value is null or undefined.
 *
 * If the default value is expensive to compute, consider using
 * {@link mapNullFn} instead. */
export declare function defaultValueFn<T>(defaultValue: T): (nullable: T | undefined | null) => T;
/** If the specified value is null or undefined, returns null.
 *
 * Otherwise, passes the specified value to the provided function and returns
 * the return value of that function. */
export declare function map<T, U>(nullable: T | undefined | null, f: (element: T) => U): U | null;
/** Returns a function that takes a nullable value as its argument.
 *
 * If the function is called with null or undefined, it returns null.
 *
 * Otherwise, the argument is passed to the callback `f` and the
 * return value of `f` is returned.
 *
 * Curried variant of {@link map}. */
export declare function mapFn<T, U>(f: (element: T) => U): (nullable: T | undefined | null) => U | null;
/** If the specified value is null or undefined, returns null.
 *
 * Otherwise, passes the specified value to the provided function and returns
 * the return value of that function.
 *
 * Alias for {@link map}. */
export declare function mapNullable<T, U>(nullable: T | undefined | null, f: (element: T) => U): U | null;
/** Returns a function that takes a nullable value as its argument.
 *
 * If the function is called with null or undefined, it returns null.
 *
 * Otherwise, the argument is passed to the callback `f` and the
 * return value of `f` is returned.
 *
 * Alias for {@link mapFn}, which is a curried variant of {@link map}. */
export declare function mapNullableFn<T, U>(f: (element: T) => U): (nullable: T | undefined | null) => U | null;
/** Returns the specified value or, if the value is null or undefined, calls
 * the provided callback and returns the result of that function call.
 *
 * Useful as an alternative to {@link defaultValue} if the default value is
 * expensive to compute. */
export declare function mapNull<T, U = T>(nullable: T | undefined | null, f: () => U): T | U;
/** Returns a function that returns the specified value or, if the value is
 * null or undefined, calls the provided callback and returns the result of
 * that function call.
 *
 * Useful as an alternative to {@link defaultValueFn} if the default value is
 * expensive to compute. */
export declare function mapNullFn<T, U = T>(f: () => U): (nullable: T | undefined | null) => T | U;
